@@ -6,7 +6,7 @@
 #' @return A character with the alphanumeric strings is returned. These strings use the prefix that is mentioned in the argument "prefix"
 buildName <- function(numOfItems, prefix)
 {
-  id <- formatC(seq(1, numOfItems), width=nchar(numOfItems), flag=0);
-  uid <- paste(prefix, id, sep="");
+  id <- formatC(seq(1, numOfItems), width=nchar(numOfItems), flag=0)
+  uid <- paste(prefix, id, sep="")
   return(uid)
 }
